@@ -503,7 +503,7 @@ class Thalassa:
 			return
 		if verbose:
 			if not self.config['verbose_log']:
-				self.log('trying to verbose log when verbose log is false')
+				#self.log('trying to verbose log when verbose log is false')
 				return
 		try:
 			with open(self.config['log_file_path'], 'a') as fh:
@@ -820,9 +820,11 @@ class Thalassa:
 			'upload_time': row[7],
 			'publish_time': row[8],
 			'owner': row[9],
+			'thumbnail': row[10],
+			'thumbnail_video_clip': row[11],
+			'summary': row[12],
+			'summary_video_clip': row[13],
 			'tags': [],
-			'thumbnail': '',
-			'thumbnail_video_clip': '',
 			'cover_file_id': '',
 			'sets': {},
 		}
@@ -904,8 +906,9 @@ class Thalassa:
 					duration INTEGER NOT NULL,
 					owner TEXT NOT NULL,
 					thumbnail TEXT NOT NULL,
+					thumbnail_video_clip TEXT NOT NULL,
 					summary TEXT NOT NULL,
-					clip TEXT NOT NULL,
+					summary_video_clip TEXT NOT NULL,
 					UNIQUE(file_id) ON CONFLICT IGNORE
 				);'''
 				cursor.execute(sql)
@@ -955,7 +958,7 @@ class Thalassa:
 					existing_file_ids.append(row[0])
 
 				# insert
-				sql = 'INSERT INTO files (file_id, upload_time, publish_time, extension, mimetype, size, width, height, duration, owner) VALUES (?,?,?,?,?,?,?,?,?,?);'
+				sql = 'INSERT INTO files (file_id, upload_time, publish_time, extension, mimetype, size, width, height, duration, owner, thumbnail, thumbnail_video_clip, summary, summary_video_clip) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?);'
 				for file_record in file_records:
 					if file_record['file_id'] in existing_file_ids:
 						collision_file_ids.append(file_record['file_id'])
@@ -972,7 +975,11 @@ class Thalassa:
 							file_record['width'],
 							file_record['height'],
 							file_record['duration'],
-							file_record['owner']
+							file_record['owner'],
+							file_record['thumbnail'],
+							file_record['thumbnail_video_clip'],
+							file_record['summary'],
+							file_record['summary_video_clip']
 						)
 					)
 				connection.commit()
@@ -1121,6 +1128,7 @@ class Thalassa:
 							values.append('set:' + set_id)
 				sql = sql[:-1] + ';'
 				cursor.execute(sql, values)
+				connection.commit()
 		except Exception as e:
 			self.log(str(e))
 			raise ValueError('Problem synchronizing sets')
@@ -1214,7 +1222,7 @@ class Thalassa:
 		self.log('getting sets file records', True)
 		if 0 == len(set_ids):
 			return
-		sql = 'SELECT file_id, mimetype, extension, size, width, height, duration, upload_time, publish_time, owner FROM files WHERE file_id in '
+		sql = 'SELECT file_id, mimetype, extension, size, width, height, duration, upload_time, publish_time, owner, thumbnail, thumbnail_video_clip, summary, summary_video_clip FROM files WHERE file_id in '
 		sql += '(SELECT file_id from tags WHERE '
 		values = []
 		for set_id in set_ids:
@@ -1235,8 +1243,6 @@ class Thalassa:
 			if file_id in file_ids_order:
 				continue
 			set_file_record = self.parse_file_record_row(row)
-			self.populate_file_record_thumbnails(set_file_record)
-			self.populate_file_record_summaries(set_file_record)
 			new_file_ids.append(set_file_record['file_id'])
 			file_records[set_file_record['file_id']] = set_file_record
 			# don't append to file_ids_order since that's just for search result ordering
@@ -1263,7 +1269,7 @@ class Thalassa:
 		self.log('getting covers files records', True)
 		if 0 == len(cover_file_ids):
 			return
-		sql = 'SELECT  file_id, mimetype, extension, size, width, height, duration, upload_time, publish_time, owner FROM files WHERE file_id IN ('
+		sql = 'SELECT  file_id, mimetype, extension, size, width, height, duration, upload_time, publish_time, owner, thumbnail, thumbnail_video_clip, summary, summary_video_clip FROM files WHERE file_id IN ('
 		values = []
 		new_file_records = 0
 		for cover_file_id in cover_file_ids:
@@ -1279,8 +1285,6 @@ class Thalassa:
 			rows = cursor.fetchall()
 			for row in rows:
 				cover_file_record = self.parse_file_record_row(row)
-				self.populate_file_record_thumbnails(cover_file_record)
-				self.populate_file_record_summaries(cover_file_record)
 				file_records[cover_file_record['file_id']] = cover_file_record
 				file_ids_order.append(cover_file_record['file_id'])
 
@@ -1500,7 +1504,7 @@ class Thalassa:
 					return (0, 0, 0, perpage, [], {}, 0)
 
 				# get requested page of results
-				sql = 'SELECT file_id, mimetype, extension, size, width, height, duration, upload_time, publish_time, owner FROM files WHERE ' + sql + ' ORDER BY ' + order_by + ' ' + sort + ', file_id ' + sort
+				sql = 'SELECT file_id, mimetype, extension, size, width, height, duration, upload_time, publish_time, owner, thumbnail, thumbnail_video_clip, summary, summary_video_clip FROM files WHERE ' + sql + ' ORDER BY ' + order_by + ' ' + sort + ', file_id ' + sort
 				if -1 != page:
 					sql += ' LIMIT ' + str(perpage) + ' OFFSET ' + str(int(perpage) * int(page))
 				else:
@@ -1519,8 +1523,6 @@ class Thalassa:
 					for row in rows:
 						file_id = row[0]
 						file_record = self.parse_file_record_row(row)
-						self.populate_file_record_thumbnails(file_record)
-						self.populate_file_record_summaries(file_record)
 						file_records[file_record['file_id']] = file_record
 						file_ids_order.append(file_record['file_id'])
 						sql += '?,'
@@ -1642,7 +1644,7 @@ class Thalassa:
 
 	# files
 	def generate_thumbnail(self, file_record):
-		self.log('generating thumbnail', True)
+		#self.log('generating thumbnail', True)
 		# skip creating thumbnails for text files
 		if 'text' == file_record['category']:
 			return []
@@ -1667,9 +1669,9 @@ class Thalassa:
 			self.log('Failed thumbnail creation for file ' + file_record['file_id'])
 			errors.append('Failed thumbnail creation')
 
+		thumbnail_video_clip_created = False
 		if self.config['generate_thumbnail_video_clips']:
 			if file_record['mimetype'] in self.category_mimes['video']:
-				thumbnail_video_clip_created = False
 				try:
 					thumbnail_video_clip_created = ffmpeg_create_thumbnail_video_clip(
 						file_path,
@@ -1685,6 +1687,27 @@ class Thalassa:
 				if not thumbnail_video_clip_created:
 					self.log('Failed thumbnail video clip creation for file ' + file_record['file_id'])
 					errors.append('Failed thumbnail video clip creation')
+
+		import sqlite3
+		try:
+			with sqlite3.connect(self.config['database_file_path']) as connection:
+				cursor = connection.cursor()
+				sql = ''
+				values = []
+				if thumbnail_created:
+					sql += 'thumbnail=?,'
+					values.append(self.config['thumbnail_format'])
+				if thumbnail_video_clip_created:
+					sql += 'thumbnail_video_clip=?,'
+					values.append('webm')
+				if 0 < len(values):
+					values.append(file_record['file_id'])
+					cursor.execute('UPDATE files SET ' + sql[:-1] + ' WHERE file_id=?;', values)
+					connection.commit()
+		except Exception as e:
+			self.log(str(e))
+			raise ValueError('Problem setting file thumbnail/clip in record')
+
 		return errors
 
 	def generate_thumbnails(self, file_records):
@@ -1736,6 +1759,29 @@ class Thalassa:
 			self.log('Created summary for file ' + file_record['file_id'] + ' was larger than original file')
 			errors.append('Created summary was larger than original file')
 
+		#TODO
+		summary_video_clip_created = False
+
+		import sqlite3
+		try:
+			with sqlite3.connect(self.config['database_file_path']) as connection:
+				cursor = connection.cursor()
+				sql = ''
+				values = []
+				if summary_created:
+					sql += 'summary=?,'
+					values.append(self.config['summary_format'])
+				if summary_video_clip_created:
+					sql += 'summary_video_clip=?,'
+					values.append('webm')
+				if 0 < len(values):
+					values.append(file_record['file_id'])
+					cursor.execute('UPDATE files SET ' + sql[:-1] + ' WHERE file_id=?;', values)
+					connection.commit()
+		except Exception as e:
+			self.log(str(e))
+			raise ValueError('Problem setting file summary/clip in record')
+
 		return errors
 
 	def generate_summaries(self, file_records):
@@ -1843,6 +1889,8 @@ class Thalassa:
 				'tags': [],
 				'thumbnail': '',
 				'thumbnail_video_clip': '',
+				'summary': '',
+				'summary_video_clip': '',
 				'cover_file_id': '',
 				'sets': {},
 			}
@@ -1850,11 +1898,15 @@ class Thalassa:
 			thumbnail_errors = self.generate_thumbnail(file_record)
 			if 0 < len(thumbnail_errors):
 				file_record['errors'] = thumbnail_errors
+			else:
+				self.populate_file_record_thumbnails(file_record)
 
 			summary_errors = self.generate_summary(file_record)
 
 			if 0 < len(summary_errors):
 				file_record['errors'] = summary_errors
+			else:
+				self.populate_file_record_summaries(file_record)
 
 			file_records[file_id] = file_record
 
@@ -1870,10 +1922,6 @@ class Thalassa:
 				filename = file_ids_to_filenames[file_id]
 				self.add_files_tags([file_id], ['filename:' + filename])
 
-		for file_id in file_records.keys():
-			self.populate_file_record_summaries(file_records[file_id])
-			self.populate_file_record_thumbnails(file_records[file_id])
-
 		return file_records
 
 	def remove_files(self, file_ids):
@@ -1921,6 +1969,21 @@ class Thalassa:
 			for path in paths:
 				if os.path.isfile(path):
 					os.remove(path)
+		import sqlite3
+		try:
+			with sqlite3.connect(self.config['database_file_path']) as connection:
+				cursor = connection.cursor()
+				sql = 'UPDATE files SET thumbnail=?,thumbnail_video_clip=? WHERE file_id IN ('
+				values = ['','']
+				for file_id in file_ids:
+					sql += '?,'
+					values.append(file_id)
+				if 0 < len(file_ids):
+					cursor.execute(sql[:-1] + ');', values)
+					connection.commit()
+		except Exception as e:
+			self.log(str(e))
+			raise ValueError('Problem removing file thumbnails from records')
 
 	def remove_file_summaries(self, file_ids):
 		self.log('removing file summaries', True)
@@ -1941,6 +2004,21 @@ class Thalassa:
 			for path in paths:
 				if os.path.isfile(path):
 					os.remove(path)
+		import sqlite3
+		try:
+			with sqlite3.connect(self.config['database_file_path']) as connection:
+				cursor = connection.cursor()
+				sql = 'UPDATE files SET summary=?,summary_video_clip=? WHERE file_id IN ('
+				values = ['','']
+				for file_id in file_ids:
+					sql += '?,'
+					values.append(file_id)
+				if 0 < len(file_ids):
+					cursor.execute(sql[:-1] + ');', values)
+					connection.commit()
+		except Exception as e:
+			self.log(str(e))
+			raise ValueError('Problem removing file summaries from records')
 
 	def rebuild_files(self, file_ids):
 		self.log('rebuilding files', True)
