@@ -242,7 +242,7 @@ function parse_file_record_string($file_record_string) {
 		'owner' => $file_record_r[9],
 		'tags' => [],
 		'thumbnail' => $file_record_r[11],
-		'thumbnail_video_clip' => $file_record_r[12],
+		'thumbnail_clip' => $file_record_r[12],
 		'cover_file_id' => $file_record_r[13],
 		'sets' => [],
 	];
@@ -349,7 +349,10 @@ function render_thumbnail($file_record, $file_records=[], $feed_thumbnail=false)
 			data-size="' . $file_record['size'] . '" 
 			data-width="' . $file_record['width'] . '" 
 			data-height="' . $file_record['height'] . '" 
-			data-duration="' . $file_record['duration'] . '" ';
+			data-duration="' . $file_record['duration'] . '" 
+			data-thumbnail="' . $file_record['thumbnail'] . '" 
+			data-thumbnail-clip="' . $file_record['thumbnail_video_clip'] . '" 
+			data-summary="' . $file_record['summary'] . '" ';
 	# add data attribute to hidden files
 	if (in_array('hidden', $file_record['tags'])) {
 		$res .= '
@@ -372,6 +375,7 @@ function render_thumbnail($file_record, $file_records=[], $feed_thumbnail=false)
 	}
 	# is there a preview clip for this thumbnail
 	if ($thumbnail_file_record) {
+		#TODO maybe also make clips of very large gifs instead of always using them
 		if ('image/gif' == $thumbnail_file_record['mimetype'] && 1 < $thumbnail_file_record['duration']) {
 			$res .= 'data-clip="' . FILES_URI . 'original/' . $thumbnail_file_record['file_id'] . '.' . $thumbnail_file_record['extension'] . '"';
 		}
@@ -655,6 +659,12 @@ function initialize_database() {
 	exec(THALASSA_CMD . ' --initialize-database', $result_output, $result_code);
 	return [$result_code, $result_output];
 }
+function rebuild_all() {
+	$result_code = null;
+	$result_output = null;
+	exec(THALASSA_CMD . ' --rebuild-all', $result_output, $result_code);
+	return [$result_code, $result_output];
+}
 function process_temp_files(
 	$temp_file_paths,
 	$datetime_string,
